@@ -1,11 +1,10 @@
 import threading, time
 
 def timer(time_length = False, message = False, variable = False):
-  try:  
+  try:
     time_length = int(time_length)
   except:
     exit("FATAL ERROR: Expected intager with 'timer()''")
-  
   global completed_message
   global timer_length
   timer_length = time_length
@@ -13,13 +12,14 @@ def timer(time_length = False, message = False, variable = False):
   def sub_timer():
     global timer_length
     global completed_message
-    time.sleep(timer_length)
+    time.sleep(timer_length-1)
+    time.sleep(0.5)
     if completed_message:
       print(completed_message)
     if variable:
       file = open(variable, "w")
       file.write("True")
-      file.close()
+      flle.close()
   t = threading.Thread(target=sub_timer)
   t.start()
 def wait(time_length = False, message = False):
